@@ -20,7 +20,5 @@ logging.getLogger().setLevel(logging.INFO)
 from .new_task import new_task
 from .new_tasks import new_tasks
 from .deep_search import deep_search
-from .static_task import static_task
-from .static_tasks import static_tasks
 from .task.models.drug import Drug
 from .task.models.gene import Gene
