@@ -13,16 +13,12 @@ from .check_result_size import check_result_size
 from .normalize_nodes import normalize_nodes
 
 
-def request_task_result(token: str, params: dict) -> dict:
-    """Returns a normalized dict of the results.
+def request_task_result(token: str) -> dict:
+    """Returns the raw task result."""
 
-    result = {drugs: {}, genes: {}}
-    """
     url_parameter = "?view=&fmt=&token=" + token
-    result = requests.get(
+
+    return requests.get(
         Url.TASK_RESULTS + url_parameter,
         verify=False
     ).json()
-    result = normalize_nodes(result)
-    result = check_result_size(result, params)
-    return result
